# automated_marking/main.py

from .repo_processing import process_repos  # Import your main processing function

def main():
    process_repos()  # Call the main processing function

if __name__ == "__main__":
    main()  # Call the main function when executed directly
